@@ -31,7 +31,7 @@
  * #BSSize is a type that facilitates work with sizes in bytes by providing
  * functions/methods that are required for parsing users input when entering
  * size, showing size in nice human-readable format, storing sizes bigger than
- * %UINT64_MAX and doing calculations with sizes without loss of
+ * UINT64_MAX and doing calculations with sizes without loss of
  * precision/information. The class is able to hold negative sizes and do
  * operations on/with them, but some of the (division and multiplication)
  * operations simply ignore the signs of the operands (check the documentation).
@@ -128,7 +128,7 @@ static char *strdup_printf (const char *fmt, ...) {
 /**
  * replace_char_with_str: (skip)
  *
- * Replaces all apperances of @char in @str with @new.
+ * Replaces all appearances of @char in @str with @new.
  */
 static char *replace_char_with_str (const char *str, char orig, const char *new) {
     uint64_t offset = 0;
@@ -147,6 +147,8 @@ static char *replace_char_with_str (const char *str, char orig, const char *new)
     /* allocate space for the string [strlen(str)] with the char replaced by the
        string [strlen(new) - 1] $count times and a \0 byte at the end [ + 1] */
     ret = malloc (sizeof(char) * (strlen(str) + (strlen(new) - 1) * count + 1));
+    if (!ret)
+        return NULL;
 
     for (i=0; str[i]; i++) {
         if (str[i] == orig)
@@ -189,6 +191,8 @@ static char *replace_str_with_str (const char *str, const char *orig, const char
     new_len = strlen (new);
     ret_size = str_len + new_len - orig_len + 1;
     ret = malloc (sizeof(char) * ret_size);
+    if (!ret)
+        return NULL;
     memset (ret, 0, ret_size);
     memcpy (ret, str, pos - str);
     dest = ret + (pos - str);
@@ -248,7 +252,7 @@ static bool multiply_size_by_unit (mpfr_t size, char *unit_str) {
         }
 
     /* not found among the binary and decimal units, let's try their translated
-       verions */
+       versions */
     for (bunit=BS_BUNIT_B; bunit < BS_BUNIT_UNDEF; bunit++)
         if (strncasecmp (unit_str, _(b_units[bunit-BS_BUNIT_B]), unit_str_len) == 0) {
             pwr = (uint64_t) bunit - BS_BUNIT_B;
@@ -277,6 +281,10 @@ static bool multiply_size_by_unit (mpfr_t size, char *unit_str) {
  */
 static void set_error (BSError **error, BSErrorCode code, char *msg) {
     *error = (BSError *) malloc (sizeof(BSError));
+    if (*error == NULL) {
+        free (msg);
+        return;
+    }
     (*error)->code = code;
     (*error)->msg = msg;
     return;
@@ -474,6 +482,11 @@ BSSize bs_size_new_from_str (const char *size_str, BSError **error) {
     }
 
     loc_size_str = replace_char_with_str (size_str, '.', radix_char);
+    if (!loc_size_str) {
+        set_error (error, BS_ERROR_INVALID_SPEC, strdup_printf ("Failed to parse size spec: %s", size_str));
+        pcre2_code_free (regex);
+        return NULL;
+    }
     str_len = strlen (loc_size_str);
 
     match_data = pcre2_match_data_create_from_pattern (regex, NULL);
@@ -663,7 +676,7 @@ char* bs_size_convert_to (const BSSize size, BSUnit unit, BSError **error) {
     }
 
     if (!found_match) {
-        set_error (error, BS_ERROR_INVALID_SPEC, "Invalid unit spec given");
+        set_error (error, BS_ERROR_INVALID_SPEC, strdup ("Invalid unit spec given"));
         mpf_clear (divisor);
         return NULL;
     }
@@ -1234,7 +1247,7 @@ BSSize bs_size_round_to_nearest (const BSSize size, const BSSize round_to, BSRou
  * functions.
  *
  * Returns: -1, 0, or 1 if @size1 is smaller, equal to or bigger than
- *          @size2 respectively comparing absolute values if @abs is %true
+ *          @size2 respectively comparing absolute values if @abs is %TRUE
  */
 int bs_size_cmp (const BSSize size1, const BSSize size2, bool abs) {
     int ret = 0;
@@ -1258,7 +1271,7 @@ int bs_size_cmp (const BSSize size1, const BSSize size2, bool abs) {
  * @bytes. This function behaves like the standard *cmp*() functions.
  *
  * Returns: -1, 0, or 1 if @size is smaller, equal to or bigger than
- *          @bytes respectively comparing absolute values if @abs is %true
+ *          @bytes respectively comparing absolute values if @abs is %TRUE
  */
 int bs_size_cmp_bytes (const BSSize size, uint64_t bytes, bool abs) {
     int ret = 0;
